@@ -1,3 +1,6 @@
+## ----echo=FALSE---------------------------------------------------------------
+knitr::include_graphics("images/diagram.png")
+
 ## -----------------------------------------------------------------------------
 dir <- system.file("extdata/salmon_dm", package="tximportData")
 files <- file.path(dir, "SRR1197474", "quant.sf") 
@@ -80,6 +83,13 @@ rowRanges(se.exons)[[1]]
 gse <- summarizeToGene(se)
 rowRanges(gse)
 
+## ----eval=FALSE---------------------------------------------------------------
+#  # unevaluated code chunk
+#  gse <- summarizeToGene(se, assignRanges="abundant")
+
+## ----echo=FALSE---------------------------------------------------------------
+knitr::include_graphics("images/assignRanges-abundant.png")
+
 ## -----------------------------------------------------------------------------
 library(org.Dm.eg.db)
 gse <- addIds(gse, "REFSEQ", gene=TRUE)
